@@ -85,6 +85,14 @@ enum
   PROP_MCW_NO_SHADOW,
 };
 
+enum
+{
+  WINDOW_DESTROYED,
+  LAST_SIGNAL
+};
+
+static guint signals[LAST_SIGNAL] = { 0 };
+
 static void mutter_window_dispose    (GObject *object);
 static void mutter_window_finalize   (GObject *object);
 static void mutter_window_constructed (GObject *object);
@@ -97,7 +105,6 @@ static void mutter_window_get_property (GObject      *object,
 					   GValue       *value,
 					   GParamSpec   *pspec);
 
-static void     mutter_window_detach     (MutterWindow *self);
 static gboolean mutter_window_has_shadow (MutterWindow *self);
 
 static void mutter_window_clear_shape_region    (MutterWindow *self);
@@ -217,6 +224,15 @@ mutter_window_class_init (MutterWindowClass *klass)
   g_object_class_install_property (object_class,
                                    PROP_MCW_NO_SHADOW,
                                    pspec);
+
+  signals[WINDOW_DESTROYED] =
+    g_signal_new ("window-destroyed",
+		  G_TYPE_FROM_CLASS (object_class),
+                  G_SIGNAL_RUN_LAST,
+		  0,
+		  NULL, NULL,
+		  g_cclosure_marshal_VOID__VOID,
+		  G_TYPE_NONE, 0);
 }
 
 static void
@@ -722,6 +738,18 @@ const char *mutter_window_get_description (MutterWindow *self)
   return self->priv->desc;
 }
 
+/**
+ * mutter_window_get_workspace:
+ * @self: #MutterWindow
+ *
+ * Returns the index of workspace on which this window is located; if the
+ * window is sticky, or is not currently located on any workspace, returns -1.
+ * This function is deprecated  and should not be used in newly written code;
+ * meta_window_get_workspace() instead.
+ *
+ * Return value: (transfer none): index of workspace on which this window is
+ * located.
+ */
 gint
 mutter_window_get_workspace (MutterWindow *self)
 {
@@ -738,6 +766,9 @@ mutter_window_get_workspace (MutterWindow *self)
 
   workspace = meta_window_get_workspace (priv->window);
 
+  if (!workspace)
+    return -1;
+
   return meta_workspace_index (workspace);
 }
 
@@ -919,12 +950,19 @@ mutter_window_effect_completed (MutterWindow *self,
     mutter_window_after_effects (self);
 }
 
-/* Called to drop our reference to a window backing pixmap that we
+/**
+ * mutter_window_detach:
+ * @self: a #MutterWindow
+ *
+ * Called to drop our reference to a window backing pixmap that we
  * previously obtained with XCompositeNameWindowPixmap. We do this
  * when the window is unmapped or when we want to update to a new
  * pixmap for a new size.
+ *
+ * This function is intended for internal use; if you are calling it externally,
+ * you are likely doing something you should not.
  */
-static void
+void
 mutter_window_detach (MutterWindow *self)
 {
   MutterWindowPrivate *priv     = self->priv;
@@ -950,6 +988,8 @@ mutter_window_destroy (MutterWindow *self)
   MetaCompScreen      *info;
   MutterWindowPrivate *priv;
 
+  g_signal_emit (self, signals[WINDOW_DESTROYED], 0);
+
   priv = self->priv;
 
   window = priv->window;
