@@ -130,6 +130,12 @@ struct _MetaWindow
   /* Whether we're fullscreen */
   guint fullscreen : 1;
 
+  /* Whether the urgent flag of WM_HINTS is set */
+  guint wm_hints_urgent : 1;
+
+  /* Set if the user moved/resized the window */
+  guint user_placed : 1;
+
   /* Area to cover when in fullscreen mode.  If _NET_WM_FULLSCREEN_MONITORS has
    * been overridden (via a client message), the window will cover the union of
    * these monitors.  If not, this is the single monitor which the window's
@@ -316,6 +322,9 @@ struct _MetaWindow
    */
   int unmaps_pending;
 
+  /* See docs for meta_window_get_stable_sequence() */
+  guint32 stable_sequence;
+
   /* set to the most recent user-interaction event timestamp that we
      know about for this window */
   guint32 net_wm_user_time;
@@ -377,6 +386,7 @@ struct _MetaWindowClass
   void (*workspace_changed) (MetaWindow *window, int  old_workspace);
   void (*focus)             (MetaWindow *window);
   void (*raised)            (MetaWindow *window);
+  void (*unmanaged)         (MetaWindow *window);
 };
 
 /* These differ from window->has_foo_func in that they consider
